@@ -7,7 +7,7 @@ use Thread::Tie ();
 # Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 use strict;
 
 # Make sure we only load stuff when we actually need it
@@ -155,6 +155,11 @@ functions in all programs by the version supplied by Thread::Rand.  To ensure
 that the right subroutines are called, you B<must> call this class method from
 within a BEGIN {} block.
 
+=head1 REQUIRED MODULES
+
+ load (any)
+ Thread::Tie (0.09)
+
 =head1 CAVEATS
 
 A bug in Perl 5.8.0 causes random sequences to be identical in threads if the
